## NOTE: Lots of files in various subdirectories have the same name (such as
## "LICENSE") so this short macro allows us to distinguish them by using their
## directory names (from the source tree) as prefixes for the files.
%define 	add_to_doc_files()	\
	mkdir -p %{buildroot}%{_docdir}/%{name}-%{version} ||: ; \
	cp -p %1  %{buildroot}%{_docdir}/%{name}-%{version}/$(echo '%1' | sed -e 's!/!.!g')

## Optional build modifications...
## --with coverage: Enables compile-time checking of code coverage.
##	(Default: No)
##
## --with debug: Enable more verbose debugging. Makes runtime a bit slower.
##	Also disables the optimized memory allocator.
##	(Default: No)
##
## --with pango: Use Pango instead of freetype2 as the font renderer.
##	CJK support is functional only with the freetype2 backend.
##	(Default: No - use freetype2)

%bcond_with 	coverage
%bcond_with 	debug
%bcond_with 	pango

Name:		webkitgtk
Version:	1.8.1
Release:	3%{?dist}
Summary:	GTK+ Web content engine library

Provides:	WebKit-gtk = %{version}-%{release}
Obsoletes:	WebKit-gtk < %{version}-%{release}

Group:		Development/Libraries
License:	LGPLv2+ and BSD
URL:		http://www.webkitgtk.org/

Source0:	http://www.webkitgtk.org/releases/webkit-%{version}.tar.xz

# add support for nspluginwrapper. 
Patch2: 	webkit-1.3.10-nspluginwrapper.patch

BuildRequires:	bison
BuildRequires:	chrpath
BuildRequires:	enchant-devel
BuildRequires:	flex
BuildRequires:	geoclue-devel
BuildRequires:	gettext
BuildRequires:	gperf
BuildRequires:	gstreamer-devel
BuildRequires:	gstreamer-plugins-base-devel
BuildRequires:	gtk2-devel
BuildRequires:	libsoup-devel >= 2.27.91
BuildRequires:	libicu-devel
BuildRequires:	libjpeg-devel
BuildRequires:	libxslt-devel
BuildRequires:	libXt-devel
BuildRequires:	pcre-devel
BuildRequires:	sqlite-devel
BuildRequires:	gobject-introspection-devel
BuildRequires:  mesa-libGL-devel
BuildRequires:  gtk-doc

## Conditional dependencies...
%if %{with pango}
BuildRequires:	pango-devel
%else
BuildRequires:	cairo-devel
BuildRequires:  cairo-gobject-devel
BuildRequires:	fontconfig-devel
BuildRequires:	freetype-devel
%endif

%description
WebKitGTK+ is the port of the portable web rendering engine WebKit to the
GTK+ platform.

%package	devel
Summary:	Development files for %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig
Requires:	gtk2-devel
Provides:	WebKit-gtk-devel = %{version}-%{release}
Obsoletes:	WebKit-gtk-devel < %{version}-%{release}

%description	devel
The %{name}-devel package contains libraries, build data, and header
files for developing applications that use %{name}.


%package	doc
Summary:	Documentation for %{name}
Group:		Documentation
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}
Provides:	WebKit-doc = %{version}-%{release}
Obsoletes:	WebKit-doc < %{version}-%{release}

%description	doc
This package contains developer documentation for %{name}.


%prep
%setup -qn "webkit-%{version}"
%patch2 -p1 -b .nspluginwrapper

%build
#%ifarch s390 %{arm}
# Use linker flags to reduce memory consumption on low-mem architectures
%global optflags %{optflags} -Wl,--no-keep-memory -Wl,--reduce-memory-overheads
#%endif
%ifarch s390
# Decrease debuginfo verbosity to reduce memory consumption even more
%global optflags %(echo %{optflags} | sed 's/-g/-g1/')
%endif

# explicitly disable JIT on ARM https://bugs.webkit.org/show_bug.cgi?id=85076

CFLAGS="%optflags -DLIBSOUP_I_HAVE_READ_BUG_594377_AND_KNOW_SOUP_PASSWORD_MANAGER_MIGHT_GO_AWAY" %configure							\
%ifarch %{arm}
                        --disable-jit                           \
%else
%ifnarch s390 s390x ppc ppc64
                        --enable-jit                            \
%endif
%endif
			--enable-geolocation			\
                        --enable-introspection                  \
                        --with-gtk=2.0                          \
                        --enable-webgl                          \
%{?with_coverage:	--enable-coverage		}	\
%{?with_debug:		--enable-debug			}	\
%{?with_pango:		--with-font-backend=pango	}

mkdir -p DerivedSources/webkit
mkdir -p DerivedSources/WebCore
mkdir -p DerivedSources/ANGLE
mkdir -p DerivedSources/WebKit2/webkit2gtk/webkit2
mkdir -p DerivedSources/InjectedBundle

# Disabled because of https://bugs.webkit.org/show_bug.cgi?id=34846
#make V=1 %{?_smp_mflags}
make V=1

%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

install -d -m 755 %{buildroot}%{_libexecdir}/%{name}
install -m 755 Programs/GtkLauncher %{buildroot}%{_libexecdir}/%{name}

# Remove lib64 rpaths
chrpath --delete %{buildroot}%{_bindir}/jsc-1
chrpath --delete %{buildroot}%{_libdir}/libwebkitgtk-1.0.so
chrpath --delete %{buildroot}%{_libexecdir}/%{name}/GtkLauncher

%find_lang webkit-2.0

## Finally, copy over and rename the various files for %%doc inclusion.
%add_to_doc_files Source/WebKit/LICENSE
%add_to_doc_files Source/WebKit/gtk/po/README
%add_to_doc_files Source/WebKit/gtk/NEWS
%add_to_doc_files Source/WebCore/icu/LICENSE
%add_to_doc_files Source/WebCore/LICENSE-APPLE
%add_to_doc_files Source/WebCore/LICENSE-LGPL-2
%add_to_doc_files Source/WebCore/LICENSE-LGPL-2.1
%add_to_doc_files Source/JavaScriptCore/COPYING.LIB
%add_to_doc_files Source/JavaScriptCore/THANKS
%add_to_doc_files Source/JavaScriptCore/AUTHORS
%add_to_doc_files Source/JavaScriptCore/icu/README
%add_to_doc_files Source/JavaScriptCore/icu/LICENSE

%clean
rm -rf %{buildroot}


%post
/sbin/ldconfig
 
%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :
fi

%posttrans
glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :


%files -f webkit-2.0.lang
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-%{version}/
%exclude %{_libdir}/*.la
%{_libdir}/libwebkitgtk-1.0.so.*
%{_libdir}/libjavascriptcoregtk-1.0.so.*
%{_libdir}/girepository-1.0/WebKit-1.0.typelib
%{_libdir}/girepository-1.0/JSCore-1.0.typelib
#{_datadir}/glib-2.0/schemas/org.webkitgtk-1.0.gschema.xml
%{_libexecdir}/%{name}/
%{_datadir}/webkitgtk-1.0

%files	devel
%defattr(-,root,root,-)
%{_bindir}/jsc-1
%{_includedir}/webkitgtk-1.0
%{_libdir}/libwebkitgtk-1.0.so
%{_libdir}/libjavascriptcoregtk-1.0.so
%{_libdir}/pkgconfig/webkit-1.0.pc
%{_libdir}/pkgconfig/javascriptcoregtk-1.0.pc
%{_datadir}/gir-1.0/WebKit-1.0.gir
%{_datadir}/gir-1.0/JSCore-1.0.gir

%files	doc
%defattr(-,root,root,-)
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/webkitgtk

%changelog
* Wed Nov 14 2012 Andrew Wyatt <andrew@fuduntu.org> - 1.48.0-14
- Build against new libraries

* Tue Sep 11 2012 Andrew Wyatt <andrew@fuduntu.org> - Version:1.8.1-Release:2
- Built for Fuduntu

* Mon May 14 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 1.8.1-2
- Explicitly disable JIT on ARM as it's not currently stable with JS heavy pages

* Wed Apr 25 2012 Kalev Lember <kalevlember@gmail.com> - 1.8.1-1
- Update to 1.8.1
- Dropped the backported patches
- Remove lib64 rpaths with chrpath
- Update gsettings rpm scriptlets

* Fri Apr 20 2012 Orion Poplwski <orion@cora.nwra.com> - 1.8.0-5
- Rebuild for icu 49

* Wed Apr 18 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 1.8.0-4
- Add upstream patch to fix crash when SSE2 isn't present
- Add upstream patch to flickering when some widgets are drawn

* Fri Apr 13 2012 Dan Horák <dan[at]danny.cz> - 1.8.0-3
- updated s390/ppc build options to match webkitgtk3

* Mon Apr 09 2012 Kalev Lember <kalevlember@gmail.com> - 1.8.0-2
- Install developer docs in -doc and mark it as noarch (#808917)
- Move the license files to the main package

* Tue Mar 27 2012 Kevin Fenzi <kevin@scrye.com> - 1.8.0-1
- Update to 1.8.0

* Tue Feb 28 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 1.6.3-2
- Add ARM to and optimise compile flags for low mem arches

* Wed Feb 01 2012 Kevin Fenzi <kevin@scrye.com> 1.6.3-1
- Update to 1.6.3. 
- enable webgl
